==> gFTL-shared-1.6.1_0+gfortran.darwin_10.ppc.tbz2: opt/local/lib/cmake/GFTL_SHAREDConfig.cmake <==
# Package configuration file


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was GFTL_SHAREDConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../../../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)

# Enables the use of the build directory directly, without having to
# specify the paths for the external packages as well
if (EXISTS "/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_fortran_gFTL-shared/gFTL-shared/work/build/extern/gFTL")
  list(APPEND CMAKE_PREFIX_PATH "/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_fortran_gFTL-shared/gFTL-shared/work/build/extern/gFTL")
elseif (EXISTS "")
  # This case covers external installations
  set(GFTL_ROOT "")
elseif (EXISTS "")
  # This case covers external installations
  set(GFTL_ROOT "")
elseif (EXISTS "/opt/local/include/GFTL")
  # Lastly, this likely from building the submodule
  set(GFTL_ROOT "/opt/local/include/GFTL")
endif()

find_dependency(GFTL)

set (GFTL_SHARED_TOP_DIR "/opt/local")
include ("${CMAKE_CURRENT_LIST_DIR}/GFTL_SHAREDTargets.cmake")

==> gFTL-shared-1.8.0_0+gfortran.darwin_10.ppc.tbz2: opt/local/lib/cmake/GFTL_SHAREDConfig.cmake <==
# Package configuration file


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was GFTL_SHAREDConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../../../../../" ABSOLUTE)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

include(CMakeFindDependencyMacro)

# Enables the use of the build directory directly, without having to
# specify the paths for the external packages as well
if (EXISTS "/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_devel_gFTL-shared/gFTL-shared/work/build/extern/gFTL")
  list(APPEND CMAKE_PREFIX_PATH "/opt/local/var/macports/build/_opt_PPCSnowLeopardPorts_devel_gFTL-shared/gFTL-shared/work/build/extern/gFTL")
elseif (EXISTS "")
  # This case covers external installations
  set(GFTL_ROOT "")
elseif (EXISTS "")
  # This case covers external installations
  set(GFTL_ROOT "")
elseif (EXISTS "/opt/local/include/GFTL")
  # Lastly, this likely from building the submodule
  set(GFTL_ROOT "/opt/local/include/GFTL")
endif()

find_dependency(GFTL)

set (GFTL_SHARED_TOP_DIR "/opt/local")
include ("${CMAKE_CURRENT_LIST_DIR}/GFTL_SHAREDTargets.cmake")
